@@ -20,14 +20,14 @@
 #define _INCLUDEEXCLUDEDIALOG_H_
 
 #include <kdialogbase.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 #include "includeexcludeview.h"
 
 class IncludeExcludeDialog: public KDialogBase
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 	IncludeExcludeDialog(TQWidget *parent);
