@@ -27,7 +27,7 @@
 class RDBListener: public TQObject
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	RDBListener();
 	TQStringList stdOut();
@@ -36,8 +36,8 @@ public:
 	bool isOk();
 
 public slots:
-	void receivedStdOut(KProcess *proc, char *buffer, int buflen);
-	void receivedStdErr(KProcess *proc, char *buffer, int buflen);
+	void receivedStdOut(TDEProcess *proc, char *buffer, int buflen);
+	void receivedStdErr(TDEProcess *proc, char *buffer, int buflen);
 
 private:
 	TQStringList m_stdOut;
